## 1.3.2

### Added

- Support 'items' property in the function passed to the JSON Schema evaluators

## 1.3.1

### Added

- Added asynchronous client and methods
- Support additional variables for custom evaluators
